/*
 * Generated by asn1c-0.9.29 (http://lionet.info/asn1c)
 * From ASN.1 module "PKIX1Explicit88"
 * 	found in "rfc5280-a.1.asn1"
 * 	`asn1c -Werror -fcompound-names -fwide-types -D asn1/asn1c -no-gen-PER -no-gen-example`
 */

#ifndef	_AlgorithmIdentifier_H_
#define	_AlgorithmIdentifier_H_

#include "asn1/asn1c/ANY.h"
#include "asn1/asn1c/OBJECT_IDENTIFIER.h"
#include "asn1/asn1c/constr_SEQUENCE.h"

/* AlgorithmIdentifier */
typedef struct AlgorithmIdentifier {
	OBJECT_IDENTIFIER_t	 algorithm;
	ANY_t	*parameters	/* OPTIONAL */;
	
	/* Context for parsing across buffer boundaries */
	asn_struct_ctx_t _asn_ctx;
} AlgorithmIdentifier_t;

/* Implementation */
extern asn_TYPE_descriptor_t asn_DEF_AlgorithmIdentifier;
extern asn_SEQUENCE_specifics_t asn_SPC_AlgorithmIdentifier_specs_1;
extern asn_TYPE_member_t asn_MBR_AlgorithmIdentifier_1[2];

#endif	/* _AlgorithmIdentifier_H_ */
