/*
 * Generated by asn1c-0.9.29 (http://lionet.info/asn1c)
 * From ASN.1 module "CryptographicMessageSyntax2004"
 * 	found in "rfc5652-12.1.asn1"
 * 	`asn1c -Werror -fcompound-names -fwide-types -D asn1/asn1c -no-gen-PER -no-gen-example`
 */

#ifndef	_EncapsulatedContentInfoPKCS7_H_
#define	_EncapsulatedContentInfoPKCS7_H_

#include "asn1/asn1c/ANY.h"
#include "asn1/asn1c/ContentType.h"
#include "asn1/asn1c/constr_SEQUENCE.h"

/* EncapsulatedContentInfoPKCS7 */
typedef struct EncapsulatedContentInfoPKCS7 {
	ContentType_t	 eContentType;
	ANY_t	*eContent	/* OPTIONAL */;
	
	/* Context for parsing across buffer boundaries */
	asn_struct_ctx_t _asn_ctx;
} EncapsulatedContentInfoPKCS7_t;

/* Implementation */
extern asn_TYPE_descriptor_t asn_DEF_EncapsulatedContentInfoPKCS7;
extern asn_SEQUENCE_specifics_t asn_SPC_EncapsulatedContentInfoPKCS7_specs_1;
extern asn_TYPE_member_t asn_MBR_EncapsulatedContentInfoPKCS7_1[2];

#endif	/* _EncapsulatedContentInfoPKCS7_H_ */
