/*
 * Generated by asn1c-0.9.29 (http://lionet.info/asn1c)
 * From ASN.1 module "RPKI-ROA"
 * 	found in "rfc6482.asn1"
 * 	`asn1c -Werror -fcompound-names -fwide-types -D asn1/asn1c -no-gen-PER -no-gen-example`
 */

#ifndef	_ROAIPAddress_H_
#define	_ROAIPAddress_H_

#include "asn1/asn1c/INTEGER.h"
#include "asn1/asn1c/IPAddress.h"
#include "asn1/asn1c/constr_SEQUENCE.h"

/* ROAIPAddress */
typedef struct ROAIPAddress {
	IPAddress_t	 address;
	INTEGER_t	*maxLength	/* OPTIONAL */;
	
	/* Context for parsing across buffer boundaries */
	asn_struct_ctx_t _asn_ctx;
} ROAIPAddress_t;

/* Implementation */
extern asn_TYPE_descriptor_t asn_DEF_ROAIPAddress;
extern asn_SEQUENCE_specifics_t asn_SPC_ROAIPAddress_specs_1;
extern asn_TYPE_member_t asn_MBR_ROAIPAddress_1[2];

#endif	/* _ROAIPAddress_H_ */
